BiometricsTokenHandler class

Biometrics token handler

Constructors

BiometricsTokenHandler({required BiometricsTokenRequestedCallback onTokenRequested, required BiometricsTokenGeneratedCallback onTokenGenerated})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
onTokenGenerated → BiometricsTokenGeneratedCallback
final
onTokenRequested → BiometricsTokenRequestedCallback
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited