DocumentCaptureResult class

Document capture result

Inheritance

Constructors

DocumentCaptureResult({required List<DocumentSide> sides, required DocumentType documentType, String? countryCode, Nfc? nfc})
const
DocumentCaptureResult.fromJson(Map<String, dynamic> json)
factory

Properties

countryCode → String?
final
documentType → DocumentType
final
hashCode → int
The hash code for this object.
no setterinherited
nfc → Nfc?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sides → List<DocumentSide>
final
type → StepNames
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited