ProofOfAddressCaptureResult class

Proof of address capture result

Inheritance

Constructors

ProofOfAddressCaptureResult({required ProofOfAddressType documentType, required List<DocumentSide> sides})
const
ProofOfAddressCaptureResult.fromJson(Map<String, dynamic> json)
factory

Properties

documentType → ProofOfAddressType
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sides → List<DocumentSide>
final
type → StepNames
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited