IdvError class

SDK Error

Constructors

IdvError({required String uuid, required ErrorType type, required ErrorCategory category, required String message})
const
IdvError.fromJson(Map<String, dynamic> json)
factory

Properties

category → ErrorCategory
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ErrorType
final
uuid → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Mirrors the native error payload (type, message, uuid).
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited