FacePhotoMediaResult class

Face photo media result

Inheritance

Constructors

FacePhotoMediaResult({required String key, required MediaFile mediaFile})
const
FacePhotoMediaResult.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String
finalinherited
mediaFile → MediaFile
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → StepNames
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited