capture_api/capture_api library

Classes

BiometricsTokenHandler
Biometrics token handler
Branding
Branding configuration.
Callbacks
SDK Callbacks configuration
CaptureResult
Base capture result class
CertificatePinning
Certificate pinning configuration
ClassicParameters
Classic parameters (uses explicit steps)
Configuration
SDK Configuration
DimensionTokens
Dimension tokens allow customising non-colour layout properties.
DocumentCaptureResult
Document capture result
DocumentFiltering
Document filtering configuration
DocumentMediaResult
Document media result
DocumentMetadata
Document metadata
DocumentOptions
Document step options
DocumentSelection
Document selection configuration
DocumentSide
A single captured document side (front or back)
DocumentStep
Document capture step
EventMetadata
Event metadata for analytics
FaceMotionCaptureResult
Face motion capture result
FaceMotionOptions
Face motion step options
FaceMotionStep
Face motion capture step
FacePhotoCaptureResult
Face photo capture result
FacePhotoMediaResult
Face photo media result
FacePhotoOptions
Face photo step options
FacePhotoStep
Face photo capture step
FaceVideoCaptureResult
Face video capture result
FaceVideoMediaResult
Face video media result
FaceVideoOptions
Face video step options
FaceVideoStep
Face video capture step
FontSource
A single source for a custom font, combining a location and format.
GenericDocument
Generic document configuration
IdvError
SDK Error
IdvEvent
IDV Event for analytics
IdvTheme
Theme configuration for the IDV SDK
Localisation
Localisation configuration
Media
A media asset with an optional accessibility description.
MediaFile
Media file information
MediaResult
Media result
Navigation configuration
Nfc
NFC chip read result
ProofOfAddressCaptureResult
Proof of address capture result
ProofOfAddressFiltering
Proof of address filtering
ProofOfAddressOptions
Proof of address step options
ProofOfAddressSelection
Proof of address selection
ProofOfAddressStep
Proof of address capture step
ResourceLocation
A pointer to a resource asset, either a local path or a remote URL.
Resources
SDK resource overrides for icons, images, animations, videos, and custom fonts.
SdkColors
SDK color tokens for theming.
SdkFont
A custom font with a name and one or more source files (allows fallbacks).
SdkParameters
Base class for SDK parameters
Step<TOptions>
Base class for all steps
StudioParameters
Studio parameters — workflow is determined by the SDK token
WelcomeStep
Welcome step - displayed at the start of the flow

Enums

DimensionTokenKey
Dimension token keys for non-colour customisation.
DocumentSideType
Which side of a document was captured
DocumentType
Document types supported by the SDK
ErrorCategory
ErrorType
FontFormat
Supported font file formats — mirrors React Native's FontFormat enum.
IconTokens
Overridable icon asset tokens.
IdvThemeMode
Theme mode for the IDV SDK
Navigation bar configuration
NfcPolicy
NFC policy for document scanning
ProofOfAddressType
Proof of address document types
ResourceLocationType
ResourceType
Resource type keys used as JSON field names — mirrors React Native's ResourceType.
StepNames
Step names for the IDV SDK flow
UserAction
User action enumeration for exit callback

Functions

captureResultFromJson(Map<String, dynamic> json) → CaptureResult
Parse capture result from JSON
Document({DocumentFiltering? documentFiltering, NfcPolicy nfcPolicy = NfcPolicy.optional, String? key}) → DocumentStep
Builder function for DocumentStep
FaceMotion({bool? showIntro, bool? recordAudio, String? key}) → FaceMotionStep
Builder function for FaceMotionStep
FacePhoto({bool? showIntro, String? key}) → FacePhotoStep
Builder function for FacePhotoStep
FaceVideo({bool? showIntro, bool? recordAudio, bool? showConfirmation, String? key}) → FaceVideoStep
Builder function for FaceVideoStep
mediaResultFromJson(Map<String, dynamic> json) → MediaResult
Parse a media result from JSON, dispatching on the type discriminator.
ProofOfAddress({ProofOfAddressFiltering? proofOfAddressFiltering, String? key}) → ProofOfAddressStep
Builder function for ProofOfAddressStep
sdkParametersFromJson(Map<String, dynamic> json) → SdkParameters
Parse SDK parameters from JSON
stepFromJson(Map<String, dynamic> json) → KnownStep
Helper to parse a step from JSON
stepsToJson(List<KnownStep> steps) → List<Map<String, dynamic>>
Helper to convert a list of steps to JSON
Welcome() → WelcomeStep
Builder function for WelcomeStep

Typedefs

AnalyticsCallback = void Function(IdvEvent event)
Analytics callback type
BiometricsTokenGeneratedCallback = void Function(String customerUserHash, String encryptedBiometricToken)
Biometrics token generated callback type
BiometricsTokenRequestedCallback = String Function(String customerHash)
Biometrics token requested callback type Returns the new token to use
CompleteCallback = void Function(Map<String, CaptureResult> result)
Complete callback type
ErrorCallback = void Function(IdvError error)
Error callback type
KnownStep = Step
Union type for all known steps
MediaCallback = void Function(MediaResult result)
Media callback type
UserExitCallback = void Function(UserAction userAction)
User exit callback type