ClassicParameters class

Classic parameters (uses explicit steps)

Inheritance

Constructors

ClassicParameters({required String sdkToken, required List<KnownStep> steps, Configuration? configuration})
const
ClassicParameters.fromJson(Map<String, dynamic> json)
factory

Properties

configuration → Configuration?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkToken → String
finalinherited
steps → List<KnownStep>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited