Configuration class

SDK Configuration

Constructors

Configuration({bool? disableAnalytics, IdvTheme? theme, Localisation? localisation, Navigation? navigation, CertificatePinning? certificatePinning})
const
Configuration.fromJson(Map<String, dynamic> json)
factory

Properties

certificatePinning → CertificatePinning?
final
disableAnalytics → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
localisation → Localisation?
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
theme → IdvTheme?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited