DocumentOptions class

Document step options

Constructors

DocumentOptions({DocumentFiltering? documentFiltering, NfcPolicy nfcPolicy = NfcPolicy.optional})
const
DocumentOptions.fromJson(Map<String, dynamic> json)
factory

Properties

documentFiltering → DocumentFiltering?
final
hashCode → int
The hash code for this object.
no setterinherited
nfcPolicy → NfcPolicy
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited