GenericDocument class

Generic document configuration

Constructors

GenericDocument({required String id, required String country, required int pages, required String title, required String subtitle})
const
GenericDocument.fromJson(Map<String, dynamic> json)
factory

Properties

country → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
pages → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle → String
final
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited