FaceMotionOptions class

Face motion step options

Constructors

FaceMotionOptions({bool showIntro = true, bool recordAudio = false})
const
FaceMotionOptions.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
recordAudio → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showIntro → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited