ProofOfAddressStep class

Proof of address capture step

Inheritance

Constructors

ProofOfAddressStep({String? key, ProofOfAddressOptions? options})
ProofOfAddressStep.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String?
finalinherited
options → ProofOfAddressOptions?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → StepNames
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited