StepNames enum

Step names for the IDV SDK flow

Inheritance
Available extensions

Values

welcome → const StepNames
const StepNames('welcome')
facePhoto → const StepNames
const StepNames('facePhoto')
faceVideo → const StepNames
const StepNames('faceVideo')
faceMotion → const StepNames
const StepNames('faceMotion')
document → const StepNames
const StepNames('document')
proofOfAddress → const StepNames
const StepNames('proofOfAddress')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(String json) → StepNames

Constants

values → const List<StepNames>
A constant List of the values in this enum, in order of their declaration.