DimensionTokens class

Dimension tokens allow customising non-colour layout properties.

Values are in density-independent pixels (dp on Android, pt on iOS).

Constructors

DimensionTokens({double? buttonBorderRadius, double? selectionListItemBorderRadius})
const
DimensionTokens.fromJson(Map<String, dynamic> json)
factory

Properties

buttonBorderRadius → double?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectionListItemBorderRadius → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited