FontFormat enum

Supported font file formats — mirrors React Native's FontFormat enum.

Note: WOFF2 is web-only and has no native support in Android/iOS.

Inheritance
Available extensions

Values

ttf → const FontFormat
const FontFormat('ttf')
otf → const FontFormat
const FontFormat('otf')
woff2 → const FontFormat
const FontFormat('woff2')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(String json) → FontFormat

Constants

values → const List<FontFormat>
A constant List of the values in this enum, in order of their declaration.