capture_api/theming/resources library

Classes

FontSource
A single source for a custom font, combining a location and format.
Media
A media asset with an optional accessibility description.
ResourceLocation
A pointer to a resource asset, either a local path or a remote URL.
Resources
SDK resource overrides for icons, images, animations, videos, and custom fonts.
SdkFont
A custom font with a name and one or more source files (allows fallbacks).

Enums

FontFormat
Supported font file formats — mirrors React Native's FontFormat enum.
IconTokens
Overridable icon asset tokens.
ResourceLocationType
ResourceType
Resource type keys used as JSON field names — mirrors React Native's ResourceType.