Resources class

SDK resource overrides for icons, images, animations, videos, and custom fonts.

Use IconTokens values as map keys for icons, e.g.:

Resources(
  icons: {IconTokens.navigationBack.value: Media(location: ...)},
)

Constructors

Resources({Map<String, Media>? icons, Map<String, Media>? images, Map<String, Media>? animations, Map<String, Media>? videos, List<SdkFont>? fonts})
const
Resources.fromJson(Map<String, dynamic> json)
factory

Properties

animations → Map<String, Media>?
Animation asset overrides. No animation tokens are currently defined.
final
fonts → List<SdkFont>?
Custom fonts to use within the SDK flow.
final
hashCode → int
The hash code for this object.
no setterinherited
icons → Map<String, Media>?
Icon asset overrides keyed by IconTokens.value.
final
images → Map<String, Media>?
Image asset overrides. No image tokens are currently defined.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
videos → Map<String, Media>?
Video asset overrides. No video tokens are currently defined.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited