capture_api/theming/theme library

Classes

Branding
Branding configuration.
DimensionTokens
Dimension tokens allow customising non-colour layout properties.
FontSource
A single source for a custom font, combining a location and format.
IdvTheme
Theme configuration for the IDV SDK
Media
A media asset with an optional accessibility description.
ResourceLocation
A pointer to a resource asset, either a local path or a remote URL.
Resources
SDK resource overrides for icons, images, animations, videos, and custom fonts.
SdkColors
SDK color tokens for theming.
SdkFont
A custom font with a name and one or more source files (allows fallbacks).

Enums

DimensionTokenKey
Dimension token keys for non-colour customisation.
FontFormat
Supported font file formats — mirrors React Native's FontFormat enum.
IconTokens
Overridable icon asset tokens.
IdvThemeMode
Theme mode for the IDV SDK
ResourceLocationType
ResourceType
Resource type keys used as JSON field names — mirrors React Native's ResourceType.