EntrustIdv class

Main entry point for the Entrust IDV SDK

Usage:

final idv = EntrustIdv(
  callbacks: Callbacks(
    onComplete: (result) => print('Complete: $result'),
    onError: (error) => print('Error: ${error.message}'),
    onUserExit: (action) => print('User exited: $action'),
  ),
);

idv.start(StudioParameters(sdkToken: 'your-token'));

Constructors

EntrustIdv({required Callbacks callbacks})
Creates a new EntrustIdv instance with the provided callbacks

Properties

callbacks → Callbacks
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Disposes of the SDK and cleans up resources
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start(SdkParameters sdkParams) → void
Starts the verification flow with the provided parameters
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited