Callbacks class
SDK Callbacks configuration
Constructors
- Callbacks({required CompleteCallback onComplete, required ErrorCallback onError, required UserExitCallback onUserExit, MediaCallback? onMedia, AnalyticsCallback? onAnalytics, BiometricsTokenHandler? biometricsTokenHandler})
-
const
Properties
- biometricsTokenHandler → BiometricsTokenHandler?
-
Handler for biometric token operations (optional)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onAnalytics → AnalyticsCallback?
-
Called for analytics events (optional)
final
- onComplete → CompleteCallback
-
Called when the verification flow completes successfully
final
- onError → ErrorCallback
-
Called when an error occurs during the verification
final
- onMedia → MediaCallback?
-
Called when media is captured (optional)
final
- onUserExit → UserExitCallback
-
Called when the user exits the verification flow
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited