capture_api/sdk_parameters
library
Classes
-
Branding
-
Branding configuration.
-
CertificatePinning
-
Certificate pinning configuration
-
ClassicParameters
-
Classic parameters (uses explicit steps)
-
Configuration
-
SDK Configuration
-
DimensionTokens
-
Dimension tokens allow customising non-colour layout properties.
-
FontSource
-
A single source for a custom font, combining a location and format.
-
IdvTheme
-
Theme configuration for the IDV SDK
-
Localisation
-
Localisation configuration
-
Media
-
A media asset with an optional accessibility description.
-
Navigation
-
Navigation configuration
-
ResourceLocation
-
A pointer to a resource asset, either a local path or a remote URL.
-
Resources
-
SDK resource overrides for icons, images, animations, videos, and custom fonts.
-
SdkColors
-
SDK color tokens for theming.
-
SdkFont
-
A custom font with a name and one or more source files (allows fallbacks).
-
SdkParameters
-
Base class for SDK parameters
-
StudioParameters
-
Studio parameters — workflow is determined by the SDK token