SdkFont class
A custom font with a name and one or more source files (allows fallbacks).
Only ResourceLocationType.remote is currently supported for font sources.
Constructors
-
SdkFont({required String name, required List<
FontSource> source}) -
const
-
SdkFont.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
source
→ List<
FontSource> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited