IdvTheme class
Theme configuration for the IDV SDK
Constructors
- IdvTheme({String? id, IdvThemeMode? mode, Branding? branding, SdkColors? lightColors, SdkColors? darkColors, Resources? resources, DimensionTokens? dimensions})
-
const
-
IdvTheme.fromJson(Map<
String, dynamic> json) -
factory
Properties
- branding → Branding?
-
final
- darkColors → SdkColors?
-
final
- dimensions → DimensionTokens?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- lightColors → SdkColors?
-
final
- mode → IdvThemeMode?
-
final
- resources → Resources?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited