entrust_idv library
Classes
- EntrustIdv
- Main entry point for the Entrust IDV SDK
Functions
-
resolveLocalFont(
String filename, FontFormat fontFormat) → Future< FontSource?> -
Builds a FontSource pointing at a font file that has been bundled
natively by the integrator (Android:
android/app/src/main/assets, iOS: added as an Xcode bundle resource and declared inInfo.plistunderUIAppFonts).